@@ -40,18 +40,18 @@ class ActionROI(argparse.Action):
                 vv = [int(v) for v in values]
             except ValueError:
                 raise argparse.ArgumentError(
-                    self, f"--roi f{' '.join(values)}: error "
+                    self, f"--roi {' '.join(values)}: error "
                           f"converting coordinates to integers")
             nx, ny = vv[1] - vv[0], vv[3] - vv[2]
             if nx <= 0 or ny <= 0 or (nx % 2 != 0) or (ny % 2 != 0):
                 raise argparse.ArgumentError(
-                    self, f"--roi f{' '.join(values)}: need an even "
+                    self, f"--roi {' '.join(values)}: need an even "
                           f"and positive size along all dimensions (nx={nx}, ny={ny})")
             if len(vv) == 6:
                 nz = vv[5] - vv[4]
                 if nz <= 0 or (nz % 2 != 0):
                     raise argparse.ArgumentError(
-                        self, f"--roi f{' '.join(values)}: need an even "
+                        self, f"--roi {' '.join(values)}: need an even "
                               f"and positive size along all dimensions "
                               f"(nx={nx}, ny={ny}, nz={nz})")
             setattr(namespace, self.dest, vv)
@@ -125,7 +125,7 @@ def make_parser(prog: str, description: str, epilog: str, default_params: dict):
     #                  help='X-ray energy in keV')
     grp.add_argument(
         '--roi', type=str, default=p['roi'], nargs='+', action=ActionROI,
-        dest='roi_user',
+        dest='roi',
         help='Region-of-interest to be used for the reconstruction. This requires '
              '4 (2D) or 6 (3D) values for xmin xmax ymin ymax [zmin zmax]. '
              'The area is taken with python conventions, i.e. pixels with indices xmin<= x < xmax and '
