@@ -166,6 +166,8 @@ class TestCDIRunner(unittest.TestCase):
         algo2 = "(Sup*ER**10)**2,psf_init=gaussian@1,DetwinRAAR**10*Sup*RAAR**50"
         for my_env in self.my_envs:
             for options in [[], ["--roi", "16", "112", "16", "112", "16", "112"],
+                            ["--roi", "16", "110", "16", "108", "16", "102", "--binning", "2"],
+                            ["--roi", "full", "--binning", "2"],
                             ["--positivity"], ["--detwin", "0"], ["--output_format", "npz"],
                             ["--support_size", "50"], ["--support_size", "50", "--support", "sphere"],
                             ["--support_size", "50", "--support", "cube"], ["--support_only_shrink"],
