@@ -745,7 +745,7 @@ def main():
         argv = [sys.argv[0]]
         for arg in sys.argv[1:]:
             arg = arg.strip()
-            if os.path.splitext(arg)[-1] in ['.cxi', '.npz', '.h5']:
+            if os.path.splitext(arg)[-1] in ['.cxi', '.npz', '.h5'] and 'modes_output' not in arg:
                 argv.append(arg)
             elif len(arg):  # weird but ' ' can occur in argv...
                 if '=' in arg:
