@@ -423,14 +423,39 @@ class ProcessingUnit(object):
                                 nodes_ct[n] = 0
                             local_ranks.append(nodes_ct[n])
                     r = mpi.scatter(local_ranks, root=0)
-                    # Before assigning the GPU, sort the found devices by their address, because the device
-                    # order can be different on two process on the same node (is that also true for opencl?)
-                    benchmark_results = [(r[0], r[1], r[0].int_ptr) for r in benchmark_results]
+
+                    def get_cl_device_id(d):
+                        """
+                        Try to use the nvidia or amd extensions for a unique GPU identification from
+                        process to process (unfortunately OpenCL does not provide any method for that..)
+
+                        :param d: the pyopencl.Device
+                        :return: the hashable device id, hopefully unique
+                        """
+                        try:
+                            # Nvidia ?
+                            return d.pci_bus_id_nv, d.pci_slot_id_nv
+                        except Exception:  # pyopencl.LogicError
+                            pass
+                        try:
+                            # AMD ?
+                            t = d.topology_amd
+                            return t.bus, t.device, t.function, t.type
+                        except Exception:  # pyopencl.LogicError
+                            pass
+                        # this probably is not unique from one process to another
+                        # device_id = r[0].int_ptr
+                        warnings.warn("Using OpenCL device 'hashable_model_and_version_identifier' to "
+                                      "identify GPU across process - this is probably not enough, "
+                                      "this should not happen for AMD or nVidia devices")
+                        return d.hashable_model_and_version_identifier
+
+                    benchmark_results = [(r[0], r[1], get_cl_device_id(r[0])) for r in benchmark_results]
                     benchmark_results = list(sorted(benchmark_results, key=lambda t: t[2]))
                     if verbose:
                         print("select_gpu using MPI: node=%s mpi_rank=%d, using GPU #%d/%d ptr:" %
                               (platform.node(), mpi.Get_rank(), r % nb, nb), benchmark_results[r % nb][0].int_ptr)
-                return self.set_device(benchmark_results[gpu_rank][r % nb], test_fft=False, verbose=verbose)
+                return self.set_device(benchmark_results[r % nb][0], test_fft=False, verbose=verbose)
 
             if ranking in ['fft', 'bandwidth']:
                 benchmark_results = sorted(benchmark_results, key=lambda t: -t[1])
