@@ -138,6 +138,11 @@ class CUProcessingUnit(ProcessingUnit):
         :param inplace: if False (the default), perform and out-of-place transform
         :return: the cufft plan
         """
+        if not (has_vkfft_cuda or has_skcuda):
+            raise ProcessingUnitException("cu_fft_get_plan: pycuda is installed, but "
+                                          "neither vkfft.cuda nor skcuda are available. "
+                                          "Please check your installed libraries or select another "
+                                          "backend (OpenCL or CPU).")
         if isinstance(ndim, bool):
             raise ProcessingUnitException("ndim is given as a bool, which probably means it "
                                           "was intended for the old 'batch' parameter. "
