@@ -1242,7 +1242,7 @@ def save_obj_probe_cxi(filename, obj, probe, wavelength, detector_distance, pixe
         if scan_area_obj is not None:
             scan_area_obj = np.flipud(scan_area_obj)  # origin at top, left corner
             # Using 'mask' from CXI specification: 0x00001000 == CXI_PIXEL_HAS_SIGNAL 'pixel signal above background'
-            s = (scan_area_obj > 0).astype(int) * 0x00001000
+            s = (scan_area_obj > 0).astype(np.int16) * 0x00001000
             result_1.create_dataset("mask", data=s, chunks=True, shuffle=True, compression="gzip")
             aux.append("mask")
             result_1[aux[-1]].attrs['note'] = "Calculated polygonal scan area"
@@ -1290,7 +1290,7 @@ def save_obj_probe_cxi(filename, obj, probe, wavelength, detector_distance, pixe
         if scan_area_probe is not None:
             scan_area_probe = np.flipud(scan_area_probe)  # origin at top, left corner
             # Using 'mask' from CXI specification: 0x00001000 == CXI_PIXEL_HAS_SIGNAL 'pixel signal above background'
-            s = (scan_area_probe > 0).astype(np.int8) * 0x00001000
+            s = (scan_area_probe > 0).astype(np.int16) * 0x00001000
             result_2.create_dataset("mask", data=s, chunks=True, shuffle=True, compression="gzip")
 
     if background is not None:
