@@ -51,7 +51,7 @@ class ActionROI(argparse.Action):
                     vv = [int(v) for v in values[0].split(',')]
                 except ValueError:
                     raise argparse.ArgumentError(
-                        self, f"--roi f{' '.join(values)}: error "
+                        self, f"--roi {' '.join(values)}: error "
                               f"converting 4 coordinates to integers")
                 nx, ny = vv[1] - vv[0], vv[3] - vv[2]
                 if nx <= 0 or ny <= 0 or (nx % 2 != 0) or (ny % 2 != 0) or (nx != ny):
@@ -70,12 +70,12 @@ class ActionROI(argparse.Action):
                 vv = [int(v) for v in values]
             except ValueError:
                 raise argparse.ArgumentError(
-                    self, f"--roi f{' '.join(values)}: error "
+                    self, f"--roi {' '.join(values)}: error "
                           f"converting 4 coordinates to integers")
             nx, ny = vv[1] - vv[0], vv[3] - vv[2]
             if nx <= 0 or ny <= 0 or (nx % 2 != 0) or (ny % 2 != 0) or (nx != ny):
                 raise argparse.ArgumentError(
-                    self, f"--roi f{' '.join(values)}: need an even "
+                    self, f"--roi {' '.join(values)}: need an even "
                           f"and equal size along both dimensions (nx={nx}, ny={ny})")
             setattr(namespace, self.dest, vv)
         else:
@@ -117,7 +117,7 @@ def make_parser(prog: str, description: str, epilog: str, default_params: dict):
              'Alternatively a list or range of scans can be given using "--scan 12 23 45"'
              'or --scan "range(12,25)" (note the quotes, necessary when using range with ()).')
     grp_in.add_argument(
-        '--max_frame', '--maxframe', type=int, default=None,
+        '--max_frame', '--maxframe', type=int, default=p['maxframe'],
         dest='maxframe', help='maximum number of frames to import')
     grp_in.add_argument(
         '--max_size', '--maxsize', type=int, default=p['maxsize'],
@@ -168,7 +168,8 @@ def make_parser(prog: str, description: str, epilog: str, default_params: dict):
              '- "maxipix": if this special name is entered, the masked pixels will be rows '
              '  and columns multiples of 258+/-3\n')
     grp_in.add_argument(
-        '--mask_iobs_max', '--maskiobsmax', type=float, default=None,
+        '--mask_iobs_max', '--maskiobsmax', type=float,
+        default=p['mask_iobs_max'],
         help='if given, all pixels with an observed intensity >= the given '
              'value are masked. This is applied frame-by-frame.')
 
@@ -193,7 +194,7 @@ def make_parser(prog: str, description: str, epilog: str, default_params: dict):
              '         data. Cropping may still be performed to get a square and '
              '         FFT-friendly size. Near-field should default to "full"\n')
     grp_in.add_argument(
-        '--rebin', '--binning', '--bin', type=int, default=None,
+        '--rebin', '--binning', '--bin', type=int, default=p['rebin'],
         help='the experimental images can be rebinned (i.e. a group of n x n pixels is replaced by a '
              'single one whose intensity is equal to the sum of all the pixels). Binning is '
              'performed last: the ROI, mask, background, pixel size should all correspond to '
@@ -203,12 +204,13 @@ def make_parser(prog: str, description: str, epilog: str, default_params: dict):
              'will be 4x faster without any loss of resolution. It is also recommended if the '
              'extent of the scanned area is smaller than the size of the Fourier (probe) array.')
     grp_in.add_argument(
-        '--xy', type=str, default=None,
+        '--xy', type=str, default=p['xy'],
         help='expression to be used for the XY positions (e.g. "-x,y",...), to compute the'
              'values from the raw input (scaling, flipping, etc..). Mathematical '
              'operations can also be used, e.g.: ``--xy=0.5*x+0.732*y,0.732*x-0.5*y``')
     grp_in.add_argument(
-        '--detector_orientation', '--detectororientation', type=str, nargs=3, default=None,
+        '--detector_orientation', '--detectororientation', type=str, nargs=3,
+        default=p['detector_orientation'],
         help='three optional flags which, if 1, will do in this order: '
              'array transpose (x/y exchange), flipud, fliplr. '
              'The changes also apply to the mask')
@@ -235,9 +237,11 @@ def make_parser(prog: str, description: str, epilog: str, default_params: dict):
     grp_in.add_argument(
         '--dark_subtract', type=float, default=False, const=True, nargs='?',
         help='use this option to subtract the dark from the observed'
-             'intensity. This is normally discouraged, as it will mess up the Poisson statistics'
-             'of the observed data, but it can be useful in the case of very high background.'
-             'If given as a simple keyword, the dark is subtracted. If given with a float,'
+             'intensity. This is DEPRECATED, as it will mess up the Poisson statistics'
+             'of the observed data (and so alters the ML optimisation). As long as '
+             '--dark is used, the background is always "subtracted" dynamically '
+             'during algorithms, but without altering the statistics.'
+             'If given as a simple keyword, the dark is pre-subtracted. If given with a float,'
              'the dark will be multiplied by this factor before subtraction')
     grp_in.add_argument(
         '--orientation_round_robin', '--orientationroundrobin', action='store_true',
@@ -364,12 +368,14 @@ def make_parser(prog: str, description: str, epilog: str, default_params: dict):
     grp_algo.add_argument('--obj_smooth', '--objsmooth', type=float, default=0,
                           help="object smoothing width during projection algorithms. Must be "
                                "associated with obj_inertia>0 for effect.")
-    grp_algo.add_argument('--obj_inertia', '--objinertia', type=float, default=0.05,
+    grp_algo.add_argument('--obj_inertia', '--objinertia', type=float,
+                          default=p['obj_inertia'],
                           help="object inertia (0-1) during projection algorithms.")
     grp_algo.add_argument('--probe_smooth', '--probesmooth', type=float, default=0,
                           help="probe smoothing width during projection algorithms. Must be "
                                "associated with probe_inertia>0 for effect.")
-    grp_algo.add_argument('--probe_inertia', '--probeinertia', type=float, default=0.005,
+    grp_algo.add_argument('--probe_inertia', '--probeinertia', type=float,
+                          default=p['probe_inertia'],
                           help="probe inertia (0-1) during projection algorithms.")
     grp_algo.add_argument('--pos_mult', '--posmult', type=float, default=5,
                           help="multiplier for the calculated position shift. Can be used to accelerate "
@@ -414,7 +420,7 @@ def make_parser(prog: str, description: str, epilog: str, default_params: dict):
 
     grp = parser.add_argument_group("Output")
     grp.add_argument('--save_plot', '--saveplot', action='store', type=str,
-                     default=False, const=True, dest='saveplot',
+                     default=p['saveplot'], const=True, dest='saveplot',
                      choices=['object_phase', 'object_rgba', 'object_real',
                               'object_imag', 'object_abs'], nargs='?',
                      help='will save plot at the end of the optimization (png file).\n'
@@ -590,7 +596,7 @@ def make_parser(prog: str, description: str, epilog: str, default_params: dict):
                           'when using "--mpi split"')
 
     grp = parser.add_argument_group("GPU")
-    grp.add_argument('--gpu', action='store', type=str, default=None,
+    grp.add_argument('--gpu', action='store', type=str, default=p['gpu'],
                      help='string matching GPU name (or part of it, case-insensitive)')
     grp.add_argument('--profile', '--profiling', action='store_true', default=False,
                      dest='profiling', help=argparse.SUPPRESS)
