@@ -1,5 +1,4 @@
 #! /opt/local/bin/python
-# -*- coding: utf-8 -*-
 
 # PyNX - Python tools for Nano-structures Crystallography
 #   (c) 2016-present : ESRF-European Synchrotron Radiation Facility
@@ -13,12 +12,12 @@
 import sys
 import os
 from pynx.ptycho.runner import PtychoRunnerException
-from pynx.ptycho.runner.hermes import PtychoRunnerHermes, PtychoRunnerScanHermes
+from pynx.ptycho.runner.hermes import PtychoRunnerHermes
 
 
 def main():
     try:
-        w = PtychoRunnerHermes(sys.argv, None, PtychoRunnerScanHermes)
+        w = PtychoRunnerHermes(sys.argv, None)
         w.process_scans()
     except PtychoRunnerException as ex:
         print('\n\n Caught exception: %s    \n' % (str(ex)))
