@@ -8,10 +8,31 @@
 
 import time
 import sys
+import os
 import platform
 import unittest
 from numpy import arange, sin, exp, pi, newaxis, float32, random, ones, isnan, sqrt
 from pynx import scattering
+from pynx.processing_unit import has_cuda, has_opencl
+
+if has_opencl:
+    from pyopencl import CompilerWarning
+    import warnings
+
+    warnings.simplefilter('ignore', CompilerWarning)
+
+exclude_cuda = False
+exclude_opencl = False
+if 'PYNX_PU' in os.environ:
+    if 'opencl' in os.environ['PYNX_PU'].lower():
+        exclude_cuda = True
+    elif 'cuda' in os.environ['PYNX_PU'].lower():
+        exclude_opencl = True
+
+if 'opencl' in sys.argv or '--opencl' in sys.argv or not has_cuda:
+    exclude_cuda = True
+if 'cuda' in sys.argv or '--cuda' in sys.argv or not has_opencl:
+    exclude_opencl = True
 
 
 def fhkl(gpu_name, nx=40, ny=40, nz=40, nh=40, nk=40, nl=40, verbose=False,
@@ -228,7 +249,7 @@ def dwba4(gpu_name, show_plot=True, verbose=True, language="OpenCL", cl_platform
         from pylab import imshow, cm, xlabel, ylabel, colorbar
         imshow(abs(fhkl_) ** 2, aspect='auto', origin='lower', extent=(h.min(), h.max(), 0, alphaf.max() * 180 / pi),
                cmap=cm.jet)
-        xlabel("$H\ (r.l.u.)$", fontsize=18)
+        xlabel(r"$H\ (r.l.u.)$", fontsize=18)
         ylabel(r"$\alpha_f\ (^\circ)$", fontsize=18)
         colorbar()
 
@@ -512,7 +533,7 @@ class TestScattering(unittest.TestCase):
                 self.assertLess(res.mean(), 1)
 
     @unittest.skipIf(scattering.fhkl.drv is None, "PyCUDA is not available")
-    @unittest.skipIf('opencl' in sys.argv, 'CUDA tests excluded')
+    @unittest.skipIf(exclude_cuda, 'CUDA tests excluded')
     def test_fhkl_cuda(self):
         n = 20
         # CUDA
@@ -524,7 +545,7 @@ class TestScattering(unittest.TestCase):
             self.assertLess(res.mean(), 1, msg=msg)
 
     @unittest.skipIf(scattering.fhkl.drv is None, "PyCUDA is not available")
-    @unittest.skipIf('opencl' in sys.argv, 'CUDA tests excluded')
+    @unittest.skipIf(exclude_cuda, 'CUDA tests excluded')
     def test_fhklo_cuda(self):
         n = 20
         scattering.fhkl.drv.init()
@@ -535,7 +556,7 @@ class TestScattering(unittest.TestCase):
             self.assertLess(res.mean(), 1, msg=msg)
 
     @unittest.skipIf(scattering.fhkl.drv is None, "PyCUDA is not available")
-    @unittest.skipIf('opencl' in sys.argv, 'CUDA tests excluded')
+    @unittest.skipIf(exclude_cuda, 'CUDA tests excluded')
     def test_fhkl_graz_cuda(self):
         n = 20
         scattering.fhkl.drv.init()
@@ -546,7 +567,7 @@ class TestScattering(unittest.TestCase):
             self.assertLess(res.mean(), 1, msg=msg)
 
     @unittest.skipIf(scattering.fhkl.drv is None, "PyCUDA is not available")
-    @unittest.skipIf('opencl' in sys.argv, 'CUDA tests excluded')
+    @unittest.skipIf(exclude_cuda, 'CUDA tests excluded')
     def test_fhklo_graz_cuda(self):
         n = 20
         for i in range(scattering.fhkl.drv.Device.count()):
@@ -556,7 +577,7 @@ class TestScattering(unittest.TestCase):
             self.assertLess(res.mean(), 1, msg=msg)
 
     @unittest.skipIf(scattering.fhkl.cl is None, "PyOpenCL is not available")
-    @unittest.skipIf('cuda' in sys.argv, 'OpenCL tests excluded')
+    @unittest.skipIf(exclude_opencl, 'OpenCL tests excluded')
     def test_fhkl_opencl(self):
         n = 20
         for p in scattering.fhkl.cl.get_platforms():
@@ -568,7 +589,7 @@ class TestScattering(unittest.TestCase):
                 self.assertLess(res.mean(), 1, msg=msg)
 
     @unittest.skipIf(scattering.fhkl.cl is None, "PyOpenCL is not available")
-    @unittest.skipIf('cuda' in sys.argv, 'OpenCL tests excluded')
+    @unittest.skipIf(exclude_opencl, 'OpenCL tests excluded')
     def test_fhklo_opencl(self):
         n = 20
         for p in scattering.fhkl.cl.get_platforms():
@@ -578,7 +599,7 @@ class TestScattering(unittest.TestCase):
                 self.assertLess(res.mean(), 1, msg=msg)
 
     @unittest.skipIf(scattering.fhkl.cl is None, "PyOpenCL is not available")
-    @unittest.skipIf('cuda' in sys.argv, 'OpenCL tests excluded')
+    @unittest.skipIf(exclude_opencl, 'OpenCL tests excluded')
     def test_fhkl_graz_opencl(self):
         n = 20
         for p in scattering.fhkl.cl.get_platforms():
@@ -588,7 +609,7 @@ class TestScattering(unittest.TestCase):
                 self.assertLess(res.mean(), 1, msg=msg)
 
     @unittest.skipIf(scattering.fhkl.cl is None, "PyOpenCL is not available")
-    @unittest.skipIf('cuda' in sys.argv, 'OpenCL tests excluded')
+    @unittest.skipIf(exclude_opencl, 'OpenCL tests excluded')
     def test_fhklo_graz_opencl(self):
         n = 20
         for p in scattering.fhkl.cl.get_platforms():
