@@ -441,7 +441,7 @@ class QuadraticPhase(CPUOperatorWavefront):
 class ThinLens(CPUOperatorWavefront):
     """
     Multiplies the wavefront by a quadratic phase factor corresponding to a thin lens with a given focal length.
-    The phase factor is: :math:`e^{-\\frac{i * \pi * (x^2 + y^2)}{\\lambda * focal\\_length}}`
+    The phase factor is: :math:`e^{-\\frac{i * \\pi * (x^2 + y^2)}{\\lambda * focal\\_length}}`
 
     Note that a too short focal_length can lead to aliasing, which will occur when the phase varies
     from more than pi from one pixel to the next. A warning will be written if this occurs at half the distance
