@@ -52,7 +52,7 @@ def colourwheel():
     rgba = complex2rgba(rhowheel * (rwheel < 1), 0.0)
     imshow(rgba)
     text(1.1, 0.5, '$0$', fontsize=14, horizontalalignment='center', verticalalignment='center', transform=ax.transAxes)
-    text(-.1, 0.5, '$\pi$', fontsize=16, horizontalalignment='center', verticalalignment='center',
+    text(-.1, 0.5, r'$\pi$', fontsize=16, horizontalalignment='center', verticalalignment='center',
          transform=ax.transAxes)
 
 
@@ -433,7 +433,7 @@ if __name__ == '__main__':
                      aspect='equal', origin='lower')
         xlabel(r"$x\ (\mu m)$", fontsize=16)
         ylabel(r"$y\ (\mu m)$", fontsize=16)
-        title("$Field\ @FZP$")
+        title(r"$Field\ @FZP$")
 
         # XZ plane near focus point
 
@@ -449,7 +449,7 @@ if __name__ == '__main__':
                      aspect='equal', origin='lower')
         xlabel(r"$x\ (\mu m)$", fontsize=16)
         ylabel(r"$y\ (\mu m)$", fontsize=16)
-        title("$Field\ @OSA$")
+        title(r"$Field\ @OSA$")
 
         # Field @focus point
         x3 = linspace(-.2e-6, .2e-6, 128)[:, newaxis]
@@ -464,7 +464,7 @@ if __name__ == '__main__':
                      aspect='equal', origin='lower')
         xlabel(r"$z\ (\mu m)$", fontsize=16)
         ylabel(r"$x\ (nm)$", fontsize=16)
-        title("$Field\ @focus\ point$")
+        title(r"$Field\ @focus\ point$")
         # Spot size
         x4 = linspace(-.2e-6, .2e-6, 256)[:, newaxis]
         y4 = 0
@@ -475,4 +475,4 @@ if __name__ == '__main__':
         plot(x4 * 1e9, abs(v4))
         xlabel(r"$x\ (nm)$", fontsize=16)
         ylabel(r"$Amplitude$")
-        title("$Field\ @focus\ point$")
+        title(r"$Field\ @focus\ point$")
